@@ -53,6 +53,14 @@ void OptionsDialog::automaticPauseDetectionSet(bool set)
 	_pauseSpeed->setEnabled(!set);
 }
 
+void OptionsDialog::pauseDetectionSet(bool set)
+{
+	_automaticPause->setEnabled(set);
+	_manualPause->setEnabled(set);
+	_pauseInterval->setEnabled(set && _manualPause->isChecked());
+	_pauseSpeed->setEnabled(set && _manualPause->isChecked());
+}
+
 QWidget *OptionsDialog::createMapPage()
 {
 	ProjectionList outputProjections(GCS::WGS84List() + Conversion::list());
@@ -377,6 +385,9 @@ QWidget *OptionsDialog::createDataPage()
 	filterTab->setLayout(filterTabLayout);
 #endif // Q_OS_MAC
 
+	_detectPauses = new QCheckBox(tr("Detect pauses"));
+	_detectPauses->setChecked(_options.detectPauses);
+
 	_automaticPause = new QRadioButton(tr("Automatic"));
 	_manualPause = new QRadioButton(tr("Custom"));
 	if (_options.automaticPause)
@@ -405,6 +416,10 @@ QWidget *OptionsDialog::createDataPage()
 	_pauseInterval->setValue(_options.pauseInterval);
 	_pauseInterval->setEnabled(_manualPause->isChecked());
 
+	pauseDetectionSet(_options.detectPauses);
+
+	connect(_detectPauses, &QCheckBox::toggled, this,
+	  &OptionsDialog::pauseDetectionSet);
 	connect(_automaticPause, &QRadioButton::toggled, this,
 	  &OptionsDialog::automaticPauseDetectionSet);
 
@@ -514,21 +529,17 @@ QWidget *OptionsDialog::createDataPage()
 	sourceTab->setLayout(sourceTabLayout);
 #endif // Q_OS_MAC
 
-
-	QHBoxLayout *pauseTypeLayout = new QHBoxLayout();
-#ifdef Q_OS_MAC
-	pauseTypeLayout->addStretch();
-#endif
+	QVBoxLayout *pauseTypeLayout = new QVBoxLayout();
 	pauseTypeLayout->addWidget(_automaticPause);
 	pauseTypeLayout->addWidget(_manualPause);
-	pauseTypeLayout->addStretch();
 
 	QFormLayout *pauseValuesLayout = new QFormLayout();
+	pauseValuesLayout->addRow(tr("Detection:"), pauseTypeLayout);
 	pauseValuesLayout->addRow(tr("Minimal speed:"), _pauseSpeed);
 	pauseValuesLayout->addRow(tr("Minimal duration:"), _pauseInterval);
 
 	QVBoxLayout *pauseLayout = new QVBoxLayout();
-	pauseLayout->addLayout(pauseTypeLayout);
+	pauseLayout->addWidget(_detectPauses);
 	pauseLayout->addLayout(pauseValuesLayout);
 
 	QWidget *pauseTab = new QWidget();
@@ -621,6 +632,8 @@ QWidget *OptionsDialog::createDEMPage()
 	_hillshadingAlpha = new PercentSlider();
 	_hillshadingAlpha->setValue(qRound((_options.hillshadingAlpha / 255.0)
 	  * 100));
+	_hillshadingLightening = new PercentSlider();
+	_hillshadingLightening->setValue(_options.hillshadingLightening * 100);
 	_hillshadingBlur = new QSpinBox();
 	_hillshadingBlur->setMaximum(10);
 	_hillshadingBlur->setSuffix(UNIT_SPACE + tr("px"));
@@ -640,6 +653,7 @@ QWidget *OptionsDialog::createDEMPage()
 
 	QFormLayout *hillshadingLayout = new QFormLayout();
 	hillshadingLayout->addRow(tr("Opacity:"), _hillshadingAlpha);
+	hillshadingLayout->addRow(tr("Lightening:"), _hillshadingLightening);
 	hillshadingLayout->addRow(tr("Blur radius:"), _hillshadingBlur);
 	hillshadingLayout->addItem(new QSpacerItem(10, 10));
 	hillshadingLayout->addRow(tr("Azimuth:"), _hillshadingAzimuth);
@@ -662,21 +676,17 @@ QWidget *OptionsDialog::createPositionPage()
 	_positionPlugin = new QComboBox();
 	_positionPlugin->addItems(plugins);
 	_positionPlugin->setCurrentIndex(_positionPlugin->findText(_options.plugin));
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
 	_pluginParameters = new PluginParameters(_positionPlugin->currentText(),
 	  _options.pluginParams);
 	connect(_positionPlugin, &QComboBox::currentTextChanged, _pluginParameters,
 	  &PluginParameters::setPlugin);
-#endif // QT 5.14
 
 	QFormLayout *pluginLayout = new QFormLayout();
 	pluginLayout->addRow(tr("Plugin:"), _positionPlugin);
 
 	QVBoxLayout *sourceLayout = new QVBoxLayout();
 	sourceLayout->addLayout(pluginLayout);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
 	sourceLayout->addWidget(_pluginParameters);
-#endif // QT 5.14
 	sourceLayout->addStretch();
 
 	QWidget *sourceTab = new QWidget();
@@ -957,6 +967,7 @@ void OptionsDialog::accept()
 	_options.cadenceFilter = _cadenceFilter->value();
 	_options.powerFilter = _powerFilter->value();
 	_options.outlierEliminate = _outlierEliminate->isChecked();
+	_options.detectPauses = _detectPauses->isChecked();
 	_options.automaticPause = _automaticPause->isChecked();
 	qreal pauseSpeed = (_units == Imperial)
 		? _pauseSpeed->value() / MS2MIH : (_units == Nautical)
@@ -987,15 +998,14 @@ void OptionsDialog::accept()
 	_options.demPassword = _demAuth->password();
 	_options.hillshadingAlpha = qRound((_hillshadingAlpha->value() / 100.0)
 	  * 255);
+	_options.hillshadingLightening = _hillshadingLightening->value() / 100.0;
 	_options.hillshadingBlur = _hillshadingBlur->value();
 	_options.hillshadingAzimuth = _hillshadingAzimuth->value();
 	_options.hillshadingAltitude = _hillshadingAltitude->value();
 	_options.hillshadingZFactor = _hillshadingZFactor->value();
 
 	_options.plugin = _positionPlugin->currentText();
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
 	_options.pluginParams = _pluginParameters->parameters();
-#endif // QT 5.14
 
 	_options.useOpenGL = _useOpenGL->isChecked();
 	_options.enableHTTP2 = _enableHTTP2->isChecked();
